@@ -4,13 +4,12 @@
 
 #include "gnumeric.h"
 #include "dependent.h"
-#include <glib-object.h>
-#include <gsf/gsf.h>
+#include <goffice/goffice.h>
 
 G_BEGIN_DECLS
 
 struct _WorkbookView {
-	GObject  base;
+	GoView  base;
 
 	Workbook *wb;
 	GPtrArray *wb_controls;
@@ -90,22 +89,22 @@ void		 wb_view_auto_expr_recalc (WorkbookView *wbv);
 
 /* I/O routines */
 gboolean wb_view_save_as (WorkbookView *wbv, GOFileSaver *fs,
-			  char const *file_name, GOCmdContext *cc);
+			  char const *uri, GOCmdContext *cc);
 gboolean wb_view_save	 (WorkbookView *wbv, GOCmdContext *cc);
 void	 wbv_save_to_output (WorkbookView *wbv, GOFileSaver const *fs,
 			     GsfOutput *output, GOIOContext *io_context);
 void     wb_view_save_to_uri (WorkbookView *wbv, GOFileSaver const *fs,
 			      char const *uri, GOIOContext *io_context);
 
-WorkbookView *wb_view_new_from_input (GsfInput *input,
-				      const char *optional_uri,
-				      GOFileOpener const *optional_format,
-				      GOIOContext *io_context,
-				      gchar const *optional_encoding);
-WorkbookView *wb_view_new_from_uri  (char const *uri,
-				     GOFileOpener const *optional_format,
-				     GOIOContext *io_context,
-				     gchar const *optional_encoding);
+WorkbookView *workbook_view_new_from_input (GsfInput *input,
+                                            const char *optional_uri,
+                                            GOFileOpener const *optional_format,
+                                            GOIOContext *io_context,
+                                            gchar const *optional_encoding);
+WorkbookView *workbook_view_new_from_uri  (char const *uri,
+                                           GOFileOpener const *optional_format,
+                                           GOIOContext *io_context,
+                                           gchar const *optional_encoding);
 
 #define WORKBOOK_VIEW_FOREACH_CONTROL(wbv, control, code)			\
 do {										\
