@@ -44,7 +44,7 @@
 #include <gsf/gsf-doc-meta-data.h>
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-meta-names.h>
-#include <glib/gi18n-lib.h>
+#include "gnm-i18n.h"
 #include <string.h>
 #include <errno.h>
 
@@ -144,8 +144,11 @@ workbook_dispose (GObject *wb_object)
 	/* Remove all contents while all sheets still exist */
 	for (ptr = sheets; ptr != NULL ; ptr = ptr->next) {
 		Sheet *sheet = ptr->data;
+		GnmRange r;
 
 		sheet_destroy_contents (sheet);
+		range_init_full_sheet (&r, sheet);
+		sheet_style_set_range (sheet, &r, sheet_style_default (sheet));
 	}
 
 	/* Now remove the sheets themselves */
@@ -262,8 +265,9 @@ workbook_class_init (GObjectClass *gobject_class)
 	gobject_class->dispose	    = workbook_dispose;
 
         g_object_class_install_property (gobject_class, RECALC_MODE,
-		 g_param_spec_boolean ("recalc-mode", "recalc-mode",
-				       _("Enable automatic recalculation."),
+		 g_param_spec_boolean ("recalc-mode",
+				       P_("Recalc mode"),
+				       P_("Enable automatic recalculation."),
 				       TRUE,
 				       GSF_PARAM_STATIC |
 				       G_PARAM_READWRITE));
@@ -1068,11 +1072,16 @@ workbook_sheet_delete (Sheet *sheet)
         g_return_if_fail (IS_SHEET (sheet));
         g_return_if_fail (IS_WORKBOOK (sheet->workbook));
 
-	gnm_app_clipboard_invalidate_sheet (sheet);
-
 	wb = sheet->workbook;
 	sheet_index = sheet->index_in_wb;
 
+	if (gnm_debug_flag ("sheets"))
+		g_printerr ("Removing sheet %s from %s\n",
+			    sheet->name_unquoted,
+			    go_doc_get_uri (GO_DOC (wb)));
+
+	gnm_app_clipboard_invalidate_sheet (sheet);
+
 	if (!wb->during_destruction) {
 		workbook_focus_other_sheet (wb, sheet);
 		/* During destruction this was already done.  */
